=======
History
=======

1.1.0 (2025-03-20)
------------------

* Unique flag is no longer required to run the pipeline

* Updated versions of packages

1.0.0 (2024-12-09)
------------------

* First release on PyPI.
